@@ -3,8 +3,6 @@
 ### Andreas Tille <tille@debian.org>
 ### GPL or EUPL
 
-VERSION="0.26"
-
 PREFIX=${PREFIX-"/usr/local"}
 
 ### Databases
@@ -13,7 +11,7 @@ FORTUNESMORE=`find data-more -maxdepth 1 -type f | sed "s?data-more/??"`
 DIRS=`find data -maxdepth 1 -type d | sed "s?data/??" | sed "/data/d"`
 
 DOC="README AUTHORS NEWS LIESMICH GPL-Deutsch"
-DOCDIR=$PREFIX/${DOCDIR:-"doc/fortune-de-$VERSION"}
+DOCDIR=$PREFIX/${DOCDIR:-"doc/fortune-de"}
 BINDIR=$PREFIX/${BINDIR:-"games"}
 MANDIR=$PREFIX/${MANDIR:-"man"}
 FORTUNEDIR=${FORTUNEDIR:-"$PREFIX/games"}
